pub fn verify<T>(name_server: &str, request: &Request<T>) -> HttpsResult<()>Available on crate feature
dns-over-https only.Expand description
Verifies the request is something we know what to deal with
pub fn verify<T>(name_server: &str, request: &Request<T>) -> HttpsResult<()>dns-over-https only.Verifies the request is something we know what to deal with