pub trait IntoName: Sized {
// Required method
fn into_name(self) -> ProtoResult<Name>;
}Expand description
Conversion into a Name
Required Methods
Sourcefn into_name(self) -> ProtoResult<Name>
fn into_name(self) -> ProtoResult<Name>
Convert this into Name
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl IntoName for &String
impl IntoName for &String
Sourcefn into_name(self) -> ProtoResult<Name>
fn into_name(self) -> ProtoResult<Name>
Performs a utf8, IDNA or punycode, translation of the &String into Name
Sourceimpl IntoName for String
impl IntoName for String
Sourcefn into_name(self) -> ProtoResult<Name>
fn into_name(self) -> ProtoResult<Name>
Performs a utf8, IDNA or punycode, translation of the String into Name
Sourceimpl<'a> IntoName for &'a str
impl<'a> IntoName for &'a str
Sourcefn into_name(self) -> ProtoResult<Name>
fn into_name(self) -> ProtoResult<Name>
Performs a utf8, IDNA or punycode, translation of the str into Name