pub trait FirstAnswer<T, E: From<ProtoError>>:
Stream<Item = Result<T, E>>
+ Unpin
+ Sized {
// Provided method
fn first_answer(self) -> FirstAnswerFuture<Self> ⓘ { ... }
}Expand description
Helper trait to convert a Stream of dns response into a Future
Provided Methods
Sourcefn first_answer(self) -> FirstAnswerFuture<Self> ⓘ
fn first_answer(self) -> FirstAnswerFuture<Self> ⓘ
Convert a Stream of dns response into a Future yielding the first answer, discarding others if any.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".